@@ -17,7 +17,11 @@ import syslog
 
 def runcmd(pamh, cmd):
   proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,)
-  output = proc.communicate()[0]
+  while proc.poll() == None:
+    pass
+  result = proc.communicate(input=None)[0]
+  if result != 0:
+    syslog.syslog("Command %(command)s failed with %(msg)s" % ( cmd, proc.stderr.read()) )
 #  print "output: %s" % output
 
 def check_and_create_localuser(pamh, user):
@@ -53,8 +57,10 @@ def check_and_create_localuser(pamh, user):
 
   # Ignore users with existing entry in /etc/passwd
   cmd = "/bin/grep \"^%s:\" /etc/passwd >/dev/null" % user
-  proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,)
-  result = proc.communicate()
+  proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, )
+  while proc.poll() == None:
+    pass
+  result = proc.communicate(input=None)[0]
   if proc.returncode == 0:
     return pamh.PAM_SUCCESS
 
